#!/bin/bash
#
# source: ftp://ftp.csx.cam.ac.uk/pub/software/programming/pcre/pcre-8.00.tar.bz2
#
# maintainer: Son|c (emmanuel.bailleul@gmail.com)
#
# ChangeLog : 
# * 7.7-54.1 :	Added patch for CVE-2008-2371
# 			Added configure options : --enable-pcregrep-libz & --enable-pcregrep-libbz2 (til request)
#			Added creation of .src file
#			Added CXXFLAGS compile option

#------------------Set Some Variables

soft="pcre"
softversion="8.12"
arch="i486"
cpu="i686"
packageversion="70.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.txz
rm -rf $dest
mkdir -p $dest/install

#-----------------Make the slack-desc files

cat << EODESC > $dest/install/slack-desc
    |-----handy-ruler------------------------------------------------------|
pcre: pcre (Perl-compatible regular expression library)
pcre:
pcre: The PCRE library is a set of functions that implement regular
pcre: expression pattern matching using the same syntax and semantics as
pcre: Perl 5, with just a few differences (documented in the man page).
pcre:
pcre:
pcre:
pcre:
pcre:
pcre:
EODESC

#------------------Set correct permissions

cd $src

chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --enable-utf8 \
  --prefix=/usr \
  --mandir=/usr/man \
  --docdir=/usr/doc/$soft-$softversion \
  --enable-unicode-properties \
  --enable-pcregrep-libz \
  --enable-pcregrep-libbz2

make
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "current ar archive" | cut -f 1 -d : | xargs strip -g 2> /dev/null
)

gzip -9 $dest/usr/man/man?/*

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#------------------( Create The *.dep File )

cd $dest
depfinder $dest > $buildir/$package.dep

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz
cd $buildir
md5sum $package.txz > $package.md5

# Creation of .src file
echo
"ftp://ftp.csx.cam.ac.uk/pub/software/programming/$soft/$soft-$softversion.tar.gz" >> $package.src
echo "http://download.zenwalk.org/people/emmanuel/$soft-$softversion/build-$soft.sh" >> $package.src

# Private use
echo "l" > $package.cat
